@@ -6,15 +6,15 @@
 """
 
 from __future__ import absolute_import
-import simplejson
+import simplejson as json
 from django.http import HttpResponse
 from varnish_bans_manager.core.helpers.commands import is_redirection
 
 
 class HttpResponseAjax(HttpResponse):
 
-    def __init__(self, commands=[], request=None):
-        self.commands = commands
+    def __init__(self, commands=None, request=None):
+        self.commands = commands if commands is not None else []
         self.is_iframe_upload = request.is_iframe_upload() if request else False
         super(HttpResponseAjax, self).__init__(
             self.dumps(),
@@ -28,9 +28,9 @@ class HttpResponseAjax(HttpResponse):
         return any(is_redirection(command) for command in self.commands)
 
     def dumps(self):
-        json = simplejson.dumps(self.commands)
+        contents = json.dumps(self.commands)
         # See http://jquery.malsup.com/form/#file-upload.
         if self.is_iframe_upload:
-            return '<textarea>' + json + '</textarea>'
+            return '<textarea>' + contents + '</textarea>'
         else:
-            return json
+            return contents
