@@ -33,37 +33,14 @@ def _default_attachment_filename(request, instance, field):
     return os.path.basename(field.path)
 
 
-###############################################################################
-
-
-def _set_common_options(self, kwargs):
-    self.private = kwargs.pop('private', True)
-    self.condition = kwargs.pop('condition', _default_condition)
-    self.attachment = kwargs.pop('attachment', False)
-    self.attachment_filename = kwargs.pop('attachment_filename', _default_attachment_filename)
-    self.content_types = kwargs.pop('content_types', None)
-    self.max_upload_size = kwargs.pop('max_upload_size', None)
-    self.strong_caching = kwargs.pop('strong_caching', True)
-    self.path_generator = kwargs.pop('path_generator', None)
-    self.original_contents_generator = kwargs.pop('contents_generator', None)
-    self.contents_generator = _wrapped_contents_generator(self.original_contents_generator) if self.original_contents_generator else None
-
-
-def _clean_content_types_and_max_upload_size(self, data):
-    try:
-        file = data.file
-        if self.content_types and not file.content_type in self.content_types:
-            raise forms.ValidationError(_('File type not supported.'))
-        elif self.max_upload_size and file._size > self.max_upload_size:
-            raise forms.ValidationError(_('Please keep filesize under %(max)s. Current filesize %(current)s.') % {
-                'max': filesizeformat(self.max_upload_size),
-                'current': filesizeformat(file._size),
-            })
-    except IOError:
-        raise forms.ValidationError(_('Invalid file.'))
-    except AttributeError:
-        pass
-    return data
+def _wrapped_contents_generator(contents_generator):
+    def wrapped(field):
+        buffer = contents_generator(field.instance)
+        # Update instance (only file field!).
+        filename = os.path.basename(field.field.path_generator(field.instance))
+        field.save(filename, ContentFile(buffer.getvalue()), save=True)
+        field.instance.save(force_update=True)
+    return wrapped
 
 
 def _wrapped_upload_to(upload_to, private, path_generator):
@@ -80,90 +57,110 @@ def _wrapped_upload_to(upload_to, private, path_generator):
         return wrapped
 
 
-def _wrapped_contents_generator(contents_generator):
-    def wrapped(field):
-        buffer = contents_generator(field.instance)
-        # Update instance (only file field!).
-        filename = os.path.basename(field.field.path_generator(field.instance))
-        field.save(filename, ContentFile(buffer.getvalue()), save=True)
-        field.instance.save(force_update=True)  # TODO: add update_fields=['file'] on django 1.5.
-    return wrapped
+###############################################################################
 
 
-def _generate(field):
-    if field.field.contents_generator:
-        tasks.GenerateFileField.enqueue(
-            field.instance._meta.app_label,
-            field.instance._meta.object_name.lower(),
-            field.instance.pk,
-            field.field.name)
+class FieldFileMixin(BaseFieldFile):
+    """
+    Mixin that adds support for public/private filesystems and file
+    contents auto-generation, as well as some useful properties.
+    """
+    @property
+    def attachment(self):
+        return self.field.attachment
+
+    @property
+    def attachment_filename(self):
+        return self.field.attachment_filename
+
+    @property
+    def condition(self):
+        return self.field.condition
+
+    @property
+    def strong_caching(self):
+        return self.field.strong_caching
+
+    @property
+    def url(self):
+        if not self and self.field.path_generator and self.field.contents_generator:
+            path = self.field.path_generator(self.instance)
+        else:
+            path = self.path
+        if self.field.private:
+            return reverse('filesystem-private-download', kwargs={
+                'app_label': self.instance._meta.app_label,
+                'model_name': self.instance._meta.object_name.lower(),
+                'object_id': self.instance.pk,
+                'field_name': self.field.name,
+                'filename': os.path.basename(path)
+            })
+        else:
+            return reverse('filesystem-public-download', kwargs={
+                'path': re.compile(r'^%s/?public/' % settings.MEDIA_ROOT).sub('', path)
+            })
+
+    def generate(self):
+        if self.field.contents_generator:
+            tasks.GenerateFileField.enqueue(
+                self.instance._meta.app_label,
+                self.instance._meta.object_name.lower(),
+                self.instance.pk,
+                self.field.name)
 
 
-def _get_url(self):
-    if not self and self.field.path_generator and self.field.contents_generator:
-        path = self.field.path_generator(self.instance)
-    else:
-        path = self.path
-    if self.field.private:
-        return reverse('filesystem-private-download', kwargs={
-            'app_label': self.instance._meta.app_label,
-            'model_name': self.instance._meta.object_name.lower(),
-            'object_id': self.instance.pk,
-            'field_name': self.field.name,
-            'filename': os.path.basename(path)
-        })
-    else:
-        return reverse('filesystem-public-download', kwargs={
-            'path': re.compile(r'^%s/?public/' % settings.MEDIA_ROOT).sub('', path)
-        })
+class FileFieldMixin(BaseFileField):
+    default_error_messages = {
+        'file_invalid': _('Invalid file.'),
+        'file_type_not_supported': _('File type not supported.'),
+        'file_too_big': _('Please keep filesize under %(max)s. Current filesize %(current)s.')
+    }
 
+    def __init__(self, **kwargs):
+        self.private = kwargs.pop('private', True)
+        self.condition = kwargs.pop('condition', _default_condition)
+        self.attachment = kwargs.pop('attachment', False)
+        self.attachment_filename = kwargs.pop('attachment_filename', _default_attachment_filename)
+        self.content_types = kwargs.pop('content_types', None)
+        self.max_upload_size = kwargs.pop('max_upload_size', None)
+        self.strong_caching = kwargs.pop('strong_caching', True)
+        self.path_generator = kwargs.pop('path_generator', None)
+        self.original_contents_generator = kwargs.pop('contents_generator', None)
+        self.contents_generator = _wrapped_contents_generator(self.original_contents_generator) if self.original_contents_generator else None
+        kwargs['upload_to'] = _wrapped_upload_to(kwargs.pop('upload_to', ''), self.private, self.path_generator)
+        super(FileFieldMixin, self).__init__(**kwargs)
 
-def _get_condition(self):
-    return self.field.condition
+    def clean(self, *args, **kwargs):
+        data = super(FileFieldMixin, self).clean(*args, **kwargs)
+        try:
+            if self.content_types and not data.file.content_type in self.content_types:
+                raise forms.ValidationError(self.error_messages['file_type_not_supported'])
+            elif self.max_upload_size and data.file._size > self.max_upload_size:
+                raise forms.ValidationError(self.error_messages['file_too_big'] % {'max': filesizeformat(self.max_upload_size), 'current': filesizeformat(data.file._size)})
+        except IOError:
+            raise forms.ValidationError(self.error_messages['file_invalid'])
+        except AttributeError:
+            pass
+        return data
 
-
-def _get_attachment(self):
-    return self.field.attachment
-
-
-def _get_attachment_filename(self):
-    return self.field.attachment_filename
-
-
-def _get_strong_caching(self):
-    return self.field.strong_caching
+    def pre_save(self, model_instance, add):
+        file = super(FileFieldMixin, self).pre_save(model_instance, add)
+        # Launch file generation (for self-generated contents).
+        if add:
+            file.generate()
+        return file
 
 
 ###############################################################################
 
 
-class FieldFile(BaseFieldFile):
-    ##
-    ## PRIVATE FILE SYSTEM.
-    ##
-
-    def generate(self):
-        _generate(self)
-
-    url = property(_get_url)
-    condition = property(_get_condition)
-    attachment = property(_get_attachment)
-    attachment_filename = property(_get_attachment_filename)
-    strong_caching = property(_get_strong_caching)
+class FieldFile(FieldFileMixin, BaseFieldFile):
+    pass
 
 
-class FileField(BaseFileField):
+class FileField(FileFieldMixin, BaseFileField):
     attr_class = FieldFile
 
-    def __init__(self, verbose_name=None, name=None, upload_to='', **kwargs):
-        _set_common_options(self, kwargs)
-        upload_to = _wrapped_upload_to(upload_to, self.private, self.path_generator)
-        super(FileField, self).__init__(verbose_name, name, upload_to, **kwargs)
-
-    def clean(self, *args, **kwargs):
-        data = super(FileField, self).clean(*args, **kwargs)
-        return _clean_content_types_and_max_upload_size(self, data)
-
 
 add_introspection_rules([(
         (FileField, ),
@@ -186,25 +183,13 @@ add_introspection_rules([(
 ###############################################################################
 
 
-class ImageFieldFile(BaseImageFieldFile):
-    ##
-    ## PRIVATE FILE SYSTEM.
-    ##
-
-    def generate(self):
-        _generate(self)
-
-    url = property(_get_url)
-    condition = property(_get_condition)
-    attachment = property(_get_attachment)
-    attachment_filename = property(_get_attachment_filename)
-    strong_caching = property(_get_strong_caching)
-
-    ##
-    ## BOUNDING BOX.
-    ##
-
+class ImageFieldFile(FieldFileMixin, BaseImageFieldFile):
+    """
+    Adds our custom mixin as well as support for resizing the image if it
+    surpases the bounding box defined by the field.
+    """
     def save(self, name, content, save=True):
+        # Resize to the bounding box if necessary.
         if self.field.max_width and self.field.max_height:
             new_content = StringIO()
             content.file.seek(0)
@@ -220,30 +205,22 @@ class ImageFieldFile(BaseImageFieldFile):
             super(ImageFieldFile, self).save(name, content, save)
 
 
-class ImageField(BaseImageField):
+class ImageField(FileFieldMixin, BaseImageField):
     attr_class = ImageFieldFile
 
-    def __init__(self, verbose_name=None, name=None, upload_to='', max_width=None, max_height=None, **kwargs):
-        _set_common_options(self, kwargs)
-        upload_to = _wrapped_upload_to(upload_to, self.private, self.path_generator)
+    def __init__(self, verbose_name=None, name=None, width_field=None,
+            height_field=None, max_width=None, max_height=None, **kwargs):
+        # Extract bounding box definition.
         self.max_width = max_width
         self.max_height = max_height
-        super(ImageField, self).__init__(verbose_name, name, upload_to=upload_to, **kwargs)
-
-    def clean(self, *args, **kwargs):
-        data = super(ImageField, self).clean(*args, **kwargs)
-        return _clean_content_types_and_max_upload_size(self, data)
+        super(ImageField, self).__init__(
+            verbose_name=verbose_name, name=name, width_field=width_field,
+            height_field=height_field, **kwargs)
 
     def formfield(self, **kwargs):
-        defaults = {'form_class': FormImageField}
-        defaults.update(kwargs)
-        return super(ImageField, self).formfield(**defaults)
-
-    def pre_save(self, model_instance, add):
-        file = super(ImageField, self).pre_save(model_instance, add)
-        if add:
-            file.generate()
-        return file
+        # Set a custom FormImageField as default form field.
+        kwargs.setdefault('form_class', FormImageField)
+        return super(ImageField, self).formfield(**kwargs)
 
 
 add_introspection_rules([(
